@@ -4,10 +4,8 @@ use std::path::Path;
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use toml::Value;
 
-use crate::bail;
 use crate::errors::{Context as _, Error, Result};
-
-pub const NAME: &str = env!("CARGO_PKG_NAME");
+use crate::{bail, NAME};
 
 pub struct Loader {
     pub xdg_dirs: xdg::BaseDirectories,
