@@ -1,5 +1,4 @@
 use std::cmp::{max, min};
-use std::convert::{TryFrom as _, TryInto as _};
 use std::ops::{Deref, DerefMut};
 use std::pin::Pin;
 use std::time::Duration;
@@ -59,9 +58,8 @@ pub struct Base {
     indicator_pattern: Pattern,
     dirty: bool,
     dirty_blink: bool,
-    blink_do: bool,
     blink_enabled: bool,
-    blink_on: bool,
+    cursor_visible: bool,
     show_selection_do: bool,
     blink_timeout: Pin<Box<Sleep>>,
     show_selection_timeout: Pin<Box<Sleep>>,
@@ -94,8 +92,7 @@ impl Base {
             has_focus: false,
             dirty: false,
             dirty_blink: false,
-            blink_on: true,
-            blink_do: config.blink,
+            cursor_visible: true,
             blink_enabled: config.blink,
             show_selection_do: false,
             blink_timeout: Box::pin(sleep(Duration::from_millis(800))),
@@ -116,6 +113,10 @@ impl Base {
         }
     }
 
+    pub fn into_pass(self) -> Passphrase {
+        Passphrase(self.pass)
+    }
+
     pub fn pass_clear(&mut self) {
         self.key_pressed();
         if self.pass.len != 0 {
@@ -143,24 +144,20 @@ impl Base {
     }
 
     pub fn init_timeouts(&mut self) {
-        if self.blink_do {
+        if self.blink_do() {
             self.reset_blink();
         }
     }
 
-    // TODO
-    pub fn requests_events(&mut self) -> bool {
-        self.blink_do || self.show_selection_do
-    }
-
     pub async fn handle_events(&mut self) {
         tokio::select! {
-            _ = &mut self.blink_timeout, if self.blink_do => {
+            _ = &mut self.blink_timeout, if self.blink_do() => {
                 self.on_blink_timeout();
             }
             _ = &mut self.show_selection_timeout, if self.show_selection_do => {
                 self.on_show_selection_timeout();
             }
+            else => std::future::pending().await
         }
     }
 
@@ -199,7 +196,7 @@ impl Base {
 
         cr.translate(self.x, self.y);
 
-        if self.has_focus && self.blink_on {
+        if self.has_focus && self.cursor_visible {
             cr.set_source(&self.foreground).unwrap();
             if sharp {
                 cr.move_to(x.floor() + 0.5, y.round());
@@ -237,10 +234,10 @@ impl Base {
 
     pub fn key_pressed(&mut self) {
         if self.blink_enabled {
-            if !self.blink_on {
+            if !self.cursor_visible {
                 self.dirty_blink = true;
             }
-            self.blink_on = true;
+            self.cursor_visible = true;
             self.reset_blink();
         }
     }
@@ -249,23 +246,26 @@ impl Base {
         self.dirty = self.dirty || is_focused != self.has_focus;
         self.has_focus = is_focused;
         if self.blink_enabled {
-            self.blink_on = is_focused;
+            self.cursor_visible = is_focused;
             if is_focused {
                 self.reset_blink();
             }
-            self.blink_do = is_focused;
         }
     }
 
+    pub fn blink_do(&self) -> bool {
+        self.has_focus && self.blink_enabled
+    }
+
     pub fn on_blink_timeout(&mut self) {
         trace!("blink timeout");
-        self.blink_on = !self.blink_on;
+        self.cursor_visible = !self.cursor_visible;
         self.dirty_blink = true;
         self.reset_blink();
     }
 
     fn reset_blink(&mut self) {
-        let duration = if self.blink_on {
+        let duration = if self.cursor_visible {
             Duration::from_millis(800)
         } else {
             Duration::from_millis(400)
@@ -278,7 +278,7 @@ impl Base {
 
 #[derive(Debug)]
 pub struct Circle {
-    base: Base,
+    pub base: Base,
     indicator_count: u32,
     inner_radius: f64,
     spacing_angle: f64,
@@ -327,7 +327,7 @@ impl Circle {
 
         let base = Base {
             width: diameter,
-            blink_on: config.blink,
+            cursor_visible: config.blink,
             ..Base::new(config, diameter, debug)
         };
 
@@ -378,10 +378,6 @@ impl Circle {
         }
     }
 
-    pub fn into_pass(self) -> Passphrase {
-        Passphrase(self.base.pass)
-    }
-
     fn init_rotation(&mut self) {
         const FULL_ROUND: f64 = 2.0 * std::f64::consts::PI;
         trace!("run animation");
@@ -581,7 +577,7 @@ impl Circle {
 
         cr.restore().unwrap();
 
-        if self.has_focus && self.blink_on {
+        if self.has_focus && self.cursor_visible {
             self.blink(cr);
         }
     }
@@ -604,7 +600,7 @@ pub struct Classic {
     radius_x: f64,
     radius_y: f64,
     indicators: Vec<Element>,
-    base: Base,
+    pub base: Base,
 }
 
 impl Deref for Classic {
@@ -635,8 +631,7 @@ impl Classic {
         let height = element_height;
         let base = Base {
             height,
-            blink_on: false,
-            blink_do: false,
+            cursor_visible: false,
             blink_enabled: false,
             ..Base::new(config, height, debug)
         };
@@ -658,10 +653,6 @@ impl Classic {
         }
     }
 
-    pub fn into_pass(self) -> Passphrase {
-        Passphrase(self.base.pass)
-    }
-
     pub fn for_width(&mut self, for_width: f64) {
         let indicator_count = min(
             max(
@@ -766,7 +757,7 @@ impl StringType {
 
 #[derive(Debug)]
 pub struct Strings {
-    base: Base,
+    pub base: Base,
     strings: StringType,
     //paste_string: String,
     //paste_width: f64,
@@ -1065,10 +1056,6 @@ impl Strings {
         }
     }
 
-    pub fn into_pass(self) -> Passphrase {
-        Passphrase(self.base.pass)
-    }
-
     pub fn paint(&self, cr: &cairo::Context) {
         trace!("strings paint start");
         assert!(self.width != 0.0);
@@ -1108,7 +1095,7 @@ impl Strings {
 
         cr.restore().unwrap();
 
-        if self.has_focus && self.blink_on {
+        if self.has_focus && self.cursor_visible {
             self.blink(cr);
         }
 
@@ -1122,12 +1109,13 @@ impl Strings {
 
     pub async fn handle_events(&mut self) {
         tokio::select! {
-            _ = &mut self.base.blink_timeout, if self.base.blink_do => {
+            _ = &mut self.base.blink_timeout, if self.base.blink_do() => {
                 self.on_blink_timeout();
             }
             _ = &mut self.base.show_selection_timeout, if self.base.show_selection_do => {
                 self.on_show_selection_timeout();
             }
+            else => std::future::pending().await
         }
     }
 
@@ -1159,17 +1147,17 @@ impl Strings {
                             - self.horizontal_spacing
                             - self.border_width)
                             * f64::from(pango::SCALE)) as i32,
-                        rec.x,
+                        rec.x(),
                     ),
-                    rec.x + rec.width - 1,
+                    rec.x() + rec.width() - 1,
                 ),
                 min(
                     max(
                         ((y - self.y - self.vertical_spacing - self.border_width)
                             * f64::from(pango::SCALE)) as i32,
-                        rec.y,
+                        rec.y(),
                     ),
-                    rec.y + rec.height - 1,
+                    rec.y() + rec.height() - 1,
                 ),
             );
             if inside {
@@ -1211,10 +1199,10 @@ impl Strings {
     }
 
     fn blink(&self, cr: &cairo::Context) {
-        if self.has_focus && self.blink_on {
+        if self.has_focus && self.cursor_visible {
             let pos = if self.show_plain || self.strings.use_cursor() {
                 let pos = self.layout.cursor_pos(self.cursor_bytes(self.cursor));
-                (pos.0.x, pos.1.x)
+                (pos.0.x(), pos.1.x())
             } else {
                 (0, 0)
             };
@@ -1364,7 +1352,7 @@ impl Disco {
     }
 
     fn set_text_do(&mut self, layout: &pango::Layout, pass_len: usize, show_paste: bool) {
-        if pass_len == 0 {
+        if pass_len == 0 && !show_paste {
             layout.set_text("");
             return;
         }
