@@ -1,5 +1,3 @@
-use std::convert::TryFrom as _;
-use std::convert::TryInto as _;
 use std::ffi::CStr;
 use std::ops::{Deref, DerefMut};
 use std::pin::Pin;
@@ -254,9 +252,9 @@ impl Indicator {
 
     pub fn into_pass(self) -> Passphrase {
         match self {
-            Self::Strings(i) => i.into_pass(),
-            Self::Circle(i) => i.into_pass(),
-            Self::Classic(i) => i.into_pass(),
+            Self::Strings(i) => i.base.into_pass(),
+            Self::Circle(i) => i.base.into_pass(),
+            Self::Classic(i) => i.base.into_pass(),
         }
     }
 
@@ -473,8 +471,8 @@ impl TextLabel {
             self.layout.pixel_extents().1
         };
         debug!("label rect: {:?}", rect);
-        let mut width: u32 = rect.width.try_into().unwrap();
-        let mut height: u32 = rect.height.try_into().unwrap();
+        let mut width: u32 = rect.width().try_into().unwrap();
+        let mut height: u32 = rect.height().try_into().unwrap();
 
         if let Some(textwidth_req) = textwidth_req {
             if width > textwidth_req {
@@ -501,10 +499,10 @@ impl TextLabel {
             }
         }
 
-        self.xoff = f64::from(rect.x);
-        self.yoff = f64::from(rect.y);
-        self.rectangle.width = f64::from(rect.width);
-        self.rectangle.height = f64::from(rect.height);
+        self.xoff = f64::from(rect.x());
+        self.yoff = f64::from(rect.y());
+        self.rectangle.width = f64::from(rect.width());
+        self.rectangle.height = f64::from(rect.height());
     }
 
     pub fn paint(&self, cr: &cairo::Context) {
@@ -820,6 +818,7 @@ impl Dialog {
         debug: bool,
     ) -> Result<Self> {
         if let Some(font_file) = config.font_file {
+            debug!("using a specific font file");
             unsafe {
                 let fc = fontconfig::FcConfigCreate();
                 if fontconfig::FcConfigSetCurrent(fc) == 0 {
@@ -836,12 +835,14 @@ impl Dialog {
         }
 
         if let Some(scale) = config.scale {
+            debug!("config scale {}", scale);
             if scale <= 0.0 {
                 bail!("invalid scale {}", scale);
             }
             cr.scale(scale, scale);
         } else if screen.height_in_pixels > 1080 {
             let scale = f64::from(screen.height_in_pixels) / 1080.0;
+            debug!("calculated scale {}", scale);
             cr.scale(scale, scale);
         }
 
@@ -961,6 +962,7 @@ impl Dialog {
             b.calc_label_position();
         }
 
+        debug!("input timeout: {:?}", config.input_timeout);
         Ok(Self {
             indicator,
             buttons,
@@ -977,7 +979,7 @@ impl Dialog {
             transparency: true,
             dirty: false,
             pango_context: components.pango_context,
-            config_direction: config.direction.map(|dir| dir.into()),
+            config_direction: config.direction.map(std::convert::Into::into),
         })
     }
 
@@ -1098,9 +1100,10 @@ impl Dialog {
                 info!("input timeout");
                 Action::Cancel
             }
-            _ = self.indicator.handle_events(), if self.indicator.requests_events() => {
+            _ = self.indicator.handle_events() => {
                 Action::Nothing
             }
+            else => std::future::pending().await
         }
     }
 
@@ -1124,7 +1127,7 @@ impl Dialog {
         Ok(())
     }
 
-    fn cairo_context_changed(&mut self, cr: &cairo::Context) {
+    pub fn cairo_context_changed(&mut self, cr: &cairo::Context) {
         for l in &mut self.labels {
             l.cairo_context_changed(cr);
         }
@@ -1194,21 +1197,28 @@ impl Dialog {
                 .reset(Instant::now().checked_add(timeout).unwrap());
         }
 
-        let action = if !isrelease && button == xproto::ButtonIndex::M2 {
-            self.mouse_middle_pressed = true;
-            Action::Nothing
-        } else if self.mouse_middle_pressed && button == xproto::ButtonIndex::M2 {
-            self.mouse_middle_pressed = false;
-            if x >= 0.0 && x < self.width as f64 && y >= 0.0 && y < self.height as f64 {
-                Action::PastePrimary
-            } else {
+        let action = match (button, isrelease) {
+            (xproto::ButtonIndex::M2, false) => {
+                self.mouse_middle_pressed = true;
+                Action::Nothing
+            }
+            (xproto::ButtonIndex::M2, true) if self.mouse_middle_pressed => {
+                self.mouse_middle_pressed = false;
+                if x >= 0.0 && x < self.width as f64 && y >= 0.0 && y < self.height as f64 {
+                    Action::PastePrimary
+                } else {
+                    Action::Nothing
+                }
+            }
+            (xproto::ButtonIndex::M1, _) => self.handle_mouse_left_button_press(x, y, isrelease),
+            _ => {
+                trace!(
+                    "unknown button action: {:?}, isrelease: {}",
+                    button,
+                    isrelease
+                );
                 Action::Nothing
             }
-        } else if button == xproto::ButtonIndex::M1 {
-            self.handle_mouse_left_button_press(x, y, isrelease)
-        } else {
-            trace!("not the left mouse button");
-            Action::Nothing
         };
 
         match action {
