@@ -4,11 +4,10 @@
 #![allow(clippy::cast_sign_loss, clippy::cast_possible_truncation)]
 #![allow(clippy::option_if_let_else)]
 
-use std::convert::TryInto as _;
 use std::os::unix::ffi::OsStrExt as _;
-use std::path::{Path, PathBuf};
+use std::path::PathBuf;
 
-use clap::{FromArgMatches as _, IntoApp as _, Parser};
+use clap::{crate_name, FromArgMatches as _, IntoApp as _, Parser};
 use log::{debug, error, info};
 use tokio::io::unix::AsyncFd;
 use tokio::signal::unix::{signal, SignalKind};
@@ -36,6 +35,7 @@ use errors::{Context as _, Result};
 use secret::Passphrase;
 
 pub const CLASS: &str = "SshAskpass";
+pub const NAME: &str = crate_name!();
 
 include!(concat!(env!("XASKPASS_BUILD_HEADER_DIR"), "/icon.rs"));
 
@@ -151,6 +151,7 @@ fn choose_visual(conn: &Connection, screen_num: usize) -> Result<(u8, xproto::Vi
                 (d.red_shift, d.green_shift, d.blue_shift, d.alpha_shift) == (16, 8, 0, 24)
             });
         if let Some(format) = format {
+            debug!("found pict format");
             // Now we need to find the visual that corresponds to this format
             if let Some(visual) = formats.screens[screen_num]
                 .depths
@@ -158,6 +159,7 @@ fn choose_visual(conn: &Connection, screen_num: usize) -> Result<(u8, xproto::Vi
                 .flat_map(|d| &d.visuals)
                 .find(|v| v.format == format.id)
             {
+                debug!("found visual");
                 return Ok((format.depth, visual.visual));
             }
         }
@@ -171,6 +173,7 @@ fn find_xcb_visualtype(conn: &Connection, visual_id: u32) -> Option<xproto::Visu
         for depth in &root.allowed_depths {
             for visual in &depth.visuals {
                 if visual.visual_id == visual_id {
+                    debug!("visual class: {:?}", visual.class);
                     return Some(*visual);
                 }
             }
@@ -236,7 +239,7 @@ async fn run_xcontext(
     let colormap = if visual_type.visual_id == screen.root_visual {
         None
     } else {
-        debug!("depth requires a new colormap");
+        debug!("visualId requires a new colormap");
         let colormap = ColormapWrapper::create_colormap(
             conn,
             xproto::ColormapAlloc::NONE,
@@ -318,7 +321,7 @@ async fn run_xcontext(
         window,
         xproto::AtomEnum::WM_CLASS,
         xproto::AtomEnum::STRING,
-        [opts.instance().as_bytes(), CLASS.as_bytes()]
+        [opts.name.as_bytes(), CLASS.as_bytes()]
             .join(&b'\0')
             .as_slice(),
     )?;
@@ -395,6 +398,7 @@ async fn run_xcontext(
         ..properties::WmSizeHints::default()
     };
     if !config.resizable {
+        debug!("trying to disable resizing");
         size_hints.max_size = Some((window_width.into(), window_height.into()));
     }
     size_hints.set_normal_hints(conn, window)?;
@@ -419,7 +423,9 @@ async fn run_xcontext(
 
     let resource_db;
     let cursor_handle = if dialog.uses_cursor() {
+        debug!("loading x11 resources");
         resource_db = x11rb::resource_manager::Database::new_from_default(conn)?;
+        debug!("initializing cursor handle");
         Some(x11rb::cursor::Handle::new(conn, screen_num, &resource_db)?)
     } else {
         None
@@ -432,8 +438,8 @@ async fn run_xcontext(
     let keyboard = keyboard::Keyboard::new(conn)?;
     dialog.set_keyboard(&keyboard);
 
-    debug!("cursor init");
     let input_cursor = if let Some(cursor_handle) = cursor_handle {
+        debug!("cursor init");
         let cursor_handle = cursor_handle.reply()?;
         Some(CursorWrapper::for_cursor(
             conn,
@@ -473,13 +479,12 @@ async fn run_xcontext(
 #[derive(Parser)]
 #[clap(
     version = env!("XASKPASS_BUILD_FULL_VERSION"),
-    about = env!("CARGO_PKG_DESCRIPTION"),
+    about,
     )]
 struct Opts {
-    #[clap(long)]
+    #[clap(long, default_value = NAME)]
     /// The instance name
-    /// (default <executable name>)
-    name: Option<String>,
+    name: String,
 
     #[clap(short, long)]
     /// Quiet; silence all logging, no matter the value of verbosity.
@@ -490,7 +495,7 @@ struct Opts {
     verbose: usize,
 
     #[clap(short, long)]
-    /// Configuration file path (default: see below)
+    /// Configuration file path [default: see below]
     config: Option<PathBuf>,
 
     #[clap(short, long)]
@@ -505,19 +510,6 @@ struct Opts {
     gen_config: bool,
 }
 
-impl Opts {
-    fn instance(&self) -> String {
-        self.name.clone().unwrap_or_else(|| {
-            std::env::args()
-                .next()
-                .as_ref()
-                .and_then(|f| Path::new(f).file_name()?.to_str())
-                .unwrap()
-                .to_string()
-        })
-    }
-}
-
 fn run() -> i32 {
     let startup_time = Instant::now();
 
@@ -525,14 +517,10 @@ fn run() -> i32 {
     let mut help = format!(
         "CONFIGURATION FILE:\n    defaults: {}{}.toml",
         cfg_loader.xdg_dirs.get_config_home().display(),
-        config::NAME,
+        NAME,
     );
     for d in cfg_loader.xdg_dirs.get_config_dirs() {
-        help.push_str(&format!(
-            ",\n              {}/{}.toml",
-            d.display(),
-            config::NAME
-        ));
+        help.push_str(&format!(",\n              {}/{}.toml", d.display(), NAME));
     }
     let app = Opts::into_app().after_help(&*help);
     let opts = Opts::from_arg_matches(&app.get_matches()).expect("from_arg_matches");
@@ -544,6 +532,11 @@ fn run() -> i32 {
             .show_module_names(true);
     }
     log.init().unwrap();
+    debug!(
+        "{} {} is starting",
+        opts.name,
+        env!("XASKPASS_BUILD_FULL_VERSION")
+    );
 
     match run_logged(&cfg_loader, opts, startup_time) {
         Ok(ret) => ret,
@@ -618,3 +611,9 @@ fn main() {
     // std::process::exit exits without dropping objects so call it in minimal stack
     std::process::exit(run());
 }
+
+#[test]
+fn verify_app() {
+    use clap::IntoApp;
+    Opts::into_app().debug_assert();
+}
